==> dojo_1.10.2+dfsg.orig.tar.xz: dojo-1.10.2+dfsg/dojo/cldr/nls/fr/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "maintenant",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "jour de la semaine",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E d/M/y",
	"field-wed-relative+0": "ce mercredi",
	"field-wed-relative+1": "mercredi prochain",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-MMMEd": "E d MMM",
	"eraNarrow": [
		"av. J.-C.",
		"ap. J.-C.",
		"ap. J.-C.",
		"EC"
	],
	"field-tue-relative+-1": "mardi dernier",
	"dayPeriods-format-wide-morning": "matin",
	"days-format-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"dateFormat-long": "d MMMM y",
	"field-fri-relative+-1": "vendredi dernier",
	"field-wed-relative+-1": "mercredi dernier",
	"months-format-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "PM",
	"dateFormat-full": "EEEE d MMMM y",
	"field-thu-relative+-1": "jeudi dernier",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-abbr-am": "AM",
	"dayPeriods-format-wide-noon": "midi",
	"dateFormatItem-yMd": "d/M/y",
	"field-era": "ère",
	"dateFormatItem-yM": "M/y",
	"months-standAlone-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"timeFormat-long": "HH:mm:ss z",
	"field-year": "année",
	"dateFormatItem-yMMM": "MMM y",
	"field-hour": "heure",
	"months-format-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"field-sat-relative+0": "ce samedi",
	"field-sat-relative+1": "samedi prochain",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dayPeriods-format-narrow-morning": "matin",
	"field-day-relative+0": "aujourd’hui",
	"field-thu-relative+0": "ce jeudi",
	"field-day-relative+1": "demain",
	"field-thu-relative+1": "jeudi prochain",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "après-demain",
	"dateFormatItem-H": "HH 'h'",
	"months-standAlone-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"quarters-standAlone-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"timeFormat-medium": "HH:mm:ss",
	"field-sun-relative+0": "ce dimanche",
	"dateFormatItem-Hm": "HH:mm",
	"field-sun-relative+1": "dimanche prochain",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"eraAbbr": [
		"av. J.-C.",
		"AEC",
		"ap. J.-C.",
		"EC"
	],
	"field-minute": "minute",
	"field-dayperiod": "cadran",
	"days-standAlone-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"dayPeriods-format-wide-night": "soir",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "hier",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "avant-hier",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "ce vendredi",
	"dateFormatItem-yMMMM": "MMMM y",
	"field-fri-relative+1": "vendredi prochain",
	"field-day": "jour",
	"days-format-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"field-zone": "fuseau horaire",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "l’année dernière",
	"dayPeriods-format-narrow-night": "soir",
	"field-month-relative+-1": "le mois dernier",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-format-abbr-pm": "PM",
	"days-format-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"eraNames": [
		"avant Jésus-Christ",
		"après Jésus-Christ",
		"ap. J.-C.",
		"EC"
	],
	"dateFormatItem-yMMMd": "d MMM y",
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "mois",
	"field-tue-relative+0": "ce mardi",
	"field-tue-relative+1": "mardi prochain",
	"dayPeriods-format-wide-am": "AM",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "ce lundi",
	"field-mon-relative+1": "lundi prochain",
	"dateFormat-short": "dd/MM/y",
	"dayPeriods-format-wide-afternoon": "après-midi",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dayPeriods-format-narrow-noon": "midi",
	"field-second": "seconde",
	"field-sat-relative+-1": "samedi dernier",
	"dateFormatItem-yMMMEd": "E d MMM y",
	"field-sun-relative+-1": "dimanche dernier",
	"field-month-relative+0": "ce mois-ci",
	"field-month-relative+1": "le mois prochain",
	"dateFormatItem-Ed": "E d",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "semaine",
	"dateFormat-medium": "d MMM y",
	"field-year-relative+0": "cette année",
	"field-week-relative+-1": "la semaine dernière",
	"field-year-relative+1": "l’année prochaine",
	"dayPeriods-format-narrow-pm": "p",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "lundi dernier",
	"field-week-relative+0": "cette semaine",
	"field-week-relative+1": "la semaine prochaine"
}
//end v1.x content
);

==> dojo_1.10.4+dfsg.orig.tar.xz: dojo-1.10.4+dfsg/dojo/cldr/nls/fr/gregorian.js <==
define(
//begin v1.x content
{
	"dateFormatItem-Ehm": "E h:mm a",
	"days-standAlone-short": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"months-format-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-second-relative+0": "maintenant",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-weekday": "jour de la semaine",
	"dateFormatItem-yQQQ": "QQQ y",
	"dateFormatItem-yMEd": "E d/M/y",
	"field-wed-relative+0": "ce mercredi",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"dateFormatItem-MMMEd": "E d MMM",
	"field-wed-relative+1": "mercredi prochain",
	"eraNarrow": [
		"av. J.-C.",
		"ap. J.-C."
	],
	"field-tue-relative+-1": "mardi dernier",
	"dayPeriods-format-wide-morning": "matin",
	"days-format-short": [
		"di",
		"lu",
		"ma",
		"me",
		"je",
		"ve",
		"sa"
	],
	"dateFormat-long": "d MMMM y",
	"field-fri-relative+-1": "vendredi dernier",
	"field-wed-relative+-1": "mercredi dernier",
	"months-format-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"dateTimeFormat-medium": "{1} {0}",
	"dayPeriods-format-wide-pm": "PM",
	"dateFormat-full": "EEEE d MMMM y",
	"field-thu-relative+-1": "jeudi dernier",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-abbr-am": "AM",
	"dayPeriods-format-wide-noon": "midi",
	"dateFormatItem-yMd": "d/M/y",
	"dateFormatItem-yM": "M/y",
	"field-era": "ère",
	"months-standAlone-wide": [
		"janvier",
		"février",
		"mars",
		"avril",
		"mai",
		"juin",
		"juillet",
		"août",
		"septembre",
		"octobre",
		"novembre",
		"décembre"
	],
	"timeFormat-short": "HH:mm",
	"quarters-format-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"timeFormat-long": "HH:mm:ss z",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-year": "année",
	"field-hour": "heure",
	"months-format-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"field-sat-relative+0": "ce samedi",
	"field-sat-relative+1": "samedi prochain",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dayPeriods-format-narrow-morning": "matin",
	"field-day-relative+0": "aujourd’hui",
	"field-day-relative+1": "demain",
	"field-thu-relative+0": "ce jeudi",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"field-day-relative+2": "après-demain",
	"field-thu-relative+1": "jeudi prochain",
	"dateFormatItem-H": "HH 'h'",
	"months-standAlone-abbr": [
		"janv.",
		"févr.",
		"mars",
		"avr.",
		"mai",
		"juin",
		"juil.",
		"août",
		"sept.",
		"oct.",
		"nov.",
		"déc."
	],
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"quarters-standAlone-wide": [
		"1er trimestre",
		"2e trimestre",
		"3e trimestre",
		"4e trimestre"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-M": "L",
	"days-standAlone-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"timeFormat-medium": "HH:mm:ss",
	"field-sun-relative+0": "ce dimanche",
	"dateFormatItem-Hm": "HH:mm",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"field-sun-relative+1": "dimanche prochain",
	"eraAbbr": [
		"av. J.-C.",
		"ap. J.-C."
	],
	"field-minute": "minute",
	"field-dayperiod": "cadran",
	"days-standAlone-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"dayPeriods-format-wide-night": "soir",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm:ss",
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-relative+-1": "hier",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} {0}",
	"field-day-relative+-2": "avant-hier",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-MEd": "E d/M",
	"dateTimeFormat-full": "{1} {0}",
	"field-fri-relative+0": "ce vendredi",
	"dateFormatItem-yMMMM": "MMMM y",
	"field-fri-relative+1": "vendredi prochain",
	"field-day": "jour",
	"days-format-wide": [
		"dimanche",
		"lundi",
		"mardi",
		"mercredi",
		"jeudi",
		"vendredi",
		"samedi"
	],
	"field-zone": "fuseau horaire",
	"dateFormatItem-y": "y",
	"months-standAlone-narrow": [
		"J",
		"F",
		"M",
		"A",
		"M",
		"J",
		"J",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year-relative+-1": "l’année dernière",
	"dayPeriods-format-narrow-night": "soir",
	"field-month-relative+-1": "le mois dernier",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-format-abbr-pm": "PM",
	"days-format-abbr": [
		"dim.",
		"lun.",
		"mar.",
		"mer.",
		"jeu.",
		"ven.",
		"sam."
	],
	"eraNames": [
		"avant Jésus-Christ",
		"après Jésus-Christ"
	],
	"dateFormatItem-yMMMd": "d MMM y",
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"J",
		"V",
		"S"
	],
	"dateFormatItem-MMM": "LLL",
	"field-month": "mois",
	"field-tue-relative+0": "ce mardi",
	"field-tue-relative+1": "mardi prochain",
	"dayPeriods-format-wide-am": "AM",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-relative+0": "ce lundi",
	"field-mon-relative+1": "lundi prochain",
	"dateFormat-short": "dd/MM/y",
	"dayPeriods-format-wide-afternoon": "après-midi",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dayPeriods-format-narrow-noon": "midi",
	"field-second": "seconde",
	"field-sat-relative+-1": "samedi dernier",
	"dateFormatItem-yMMMEd": "E d MMM y",
	"field-sun-relative+-1": "dimanche dernier",
	"field-month-relative+0": "ce mois-ci",
	"field-month-relative+1": "le mois prochain",
	"dateFormatItem-Ed": "E d",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-week": "semaine",
	"dateFormat-medium": "d MMM y",
	"field-year-relative+0": "cette année",
	"field-week-relative+-1": "la semaine dernière",
	"field-year-relative+1": "l’année prochaine",
	"dayPeriods-format-narrow-pm": "p",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "lundi dernier",
	"field-week-relative+0": "cette semaine",
	"field-week-relative+1": "la semaine prochaine"
}
//end v1.x content
);
